@@ -1,8 +1,16 @@
-from neomodel import (StructuredNode, StructuredRel, Relationship, RelationshipTo,
-        StringProperty, DateTimeProperty, DeflateError)
 from datetime import datetime
+
+from pytest import raises
 import pytz
 
+from neomodel import (StructuredNode, StructuredRel, Relationship, RelationshipTo,
+                      StringProperty, DateTimeProperty, DeflateError)
+
+HOOKS_CALLED = {
+    'pre_save': 0,
+    'post_save': 0
+}
+
 
 class FriendRel(StructuredRel):
     since = DateTimeProperty(default=lambda: datetime.now(pytz.utc))
@@ -11,6 +19,12 @@ class FriendRel(StructuredRel):
 class HatesRel(FriendRel):
     reason = StringProperty()
 
+    def pre_save(self):
+        HOOKS_CALLED['pre_save'] += 1
+
+    def post_save(self):
+        HOOKS_CALLED['post_save'] += 1
+
 
 class Badger(StructuredNode):
     name = StringProperty(unique_index=True)
@@ -41,8 +55,8 @@ def test_either_connect_with_rel_model():
     # I've tried everything possible to correct this to no avail
     paul = new_rel.start_node()
     tom = new_rel.end_node()
-    assert paul.name == 'Paul'
-    assert tom.name == 'Tom'
+    assert paul.name == 'Tom'
+    assert tom.name == 'Paul'
 
 
 def test_direction_connect_with_rel_model():
@@ -71,20 +85,12 @@ def test_direction_connect_with_rel_model():
 
     # test deflate checking
     rel.since = "2:30pm"
-    try:
+    with raises(DeflateError):
         rel.save()
-    except DeflateError:
-        assert True
-    else:
-        assert False
 
     # check deflate check via connect
-    try:
+    with raises(DeflateError):
         paul.hates.connect(ian, {'reason': "thinks paul should bath more often", 'since': '2:30pm'})
-    except DeflateError:
-        assert True
-    else:
-        assert False
 
 
 def test_traversal_where_clause():
@@ -98,3 +104,45 @@ def test_traversal_where_clause():
     assert rel2.since > now
     friends = tim.friend.match(since__gt=now)
     assert len(friends) == 1
+
+
+def test_multiple_rels_exist_issue_223():
+    # check a badger can dislike a stoat for multiple reasons
+    phill = Badger(name="Phill").save()
+    ian = Stoat(name="Stoat").save()
+
+    rel_a = phill.hates.connect(ian, {'reason': 'a'})
+    rel_b = phill.hates.connect(ian, {'reason': 'b'})
+    assert rel_a.id != rel_b.id
+
+    ian_a = phill.hates.match(reason='a')[0]
+    ian_b = phill.hates.match(reason='b')[0]
+    assert ian_a.id == ian_b.id
+
+
+def test_retrieve_all_rels():
+    tom = Badger(name="tom").save()
+    ian = Stoat(name="ian").save()
+
+    rel_a = tom.hates.connect(ian, {'reason': 'a'})
+    rel_b = tom.hates.connect(ian, {'reason': 'b'})
+
+    rels = tom.hates.all_relationships(ian)
+    assert len(rels) == 2
+    assert rels[0].id in [rel_a.id, rel_b.id]
+    assert rels[1].id in [rel_a.id, rel_b.id]
+
+
+def test_save_hook_on_rel_model():
+    HOOKS_CALLED['pre_save'] = 0
+    HOOKS_CALLED['post_save'] = 0
+
+    paul = Badger(name="PaulB").save()
+    ian = Stoat(name="IanS").save()
+
+    rel = ian.hates.connect(paul, {'reason': "yadda yadda"})
+    rel.save()
+
+    assert HOOKS_CALLED['pre_save'] == 2
+    assert HOOKS_CALLED['post_save'] == 2
+
